import { Component, OnInit } from '@angular/core';
import { HttpResponse } from '@angular/common/http';
// eslint-disable-next-line @typescript-eslint/no-unused-vars
import { FormBuilder, Validators } from '@angular/forms';
import { ActivatedRoute } from '@angular/router';
import { Observable } from 'rxjs';

import { IWatchListEntry, WatchListEntry } from 'app/shared/model/watch-list-entry.model';
import { WatchListEntryService } from './watch-list-entry.service';
import { IUserWatchList } from 'app/shared/model/user-watch-list.model';
import { UserWatchListService } from 'app/entities/user-watch-list/user-watch-list.service';

@Component({
  selector: 'jhi-watch-list-entry-update',
  templateUrl: './watch-list-entry-update.component.html',
})
export class WatchListEntryUpdateComponent implements OnInit {
  isSaving = false;
  userwatchlists: IUserWatchList[] = [];

  editForm = this.fb.group({
    id: [],
    exerciseId: [null, [Validators.required]],
    exerciseName: [],
    watchlistIdId: [null, Validators.required],
  });

  constructor(
    protected watchListEntryService: WatchListEntryService,
    protected userWatchListService: UserWatchListService,
    protected activatedRoute: ActivatedRoute,
    private fb: FormBuilder
  ) {}

  ngOnInit(): void {
    this.activatedRoute.data.subscribe(({ watchListEntry }) => {
      this.updateForm(watchListEntry);

      this.userWatchListService.query().subscribe((res: HttpResponse<IUserWatchList[]>) => (this.userwatchlists = res.body || []));
    });
  }

  updateForm(watchListEntry: IWatchListEntry): void {
    this.editForm.patchValue({
      id: watchListEntry.id,
      exerciseId: watchListEntry.exerciseId,
      exerciseName: watchListEntry.exerciseName,
      watchlistIdId: watchListEntry.watchlistIdId,
    });
  }

  previousState(): void {
    window.history.back();
  }

  save(): void {
    this.isSaving = true;
    const watchListEntry = this.createFromForm();
    if (watchListEntry.id !== undefined) {
      this.subscribeToSaveResponse(this.watchListEntryService.update(watchListEntry));
    } else {
      this.subscribeToSaveResponse(this.watchListEntryService.create(watchListEntry));
    }
  }

  private createFromForm(): IWatchListEntry {
    return {
      ...new WatchListEntry(),
      id: this.editForm.get(['id'])!.value,
      exerciseId: this.editForm.get(['exerciseId'])!.value,
      exerciseName: this.editForm.get(['exerciseName'])!.value,
      watchlistIdId: this.editForm.get(['watchlistIdId'])!.value,
    };
  }

  protected subscribeToSaveResponse(result: Observable<HttpResponse<IWatchListEntry>>): void {
    result.subscribe(
      () => this.onSaveSuccess(),
      () => this.onSaveError()
    );
  }

  protected onSaveSuccess(): void {
    this.isSaving = false;
    this.previousState();
  }

  protected onSaveError(): void {
    this.isSaving = false;
  }

  trackById(index: number, item: IUserWatchList): any {
    return item.id;
  }
}
